@@ -46,10 +46,12 @@ class Command(BaseCommand):
         sep31_qparams = Q(
             protocol=Transaction.PROTOCOL.sep31,
             status=Transaction.STATUS.pending_receiver,
+            kind=Transaction.KIND.send,
         )
         sep6_24_qparams = Q(
             protocol__in=[Transaction.PROTOCOL.sep24, Transaction.PROTOCOL.sep6],
             status=Transaction.STATUS.pending_anchor,
+            kind=Transaction.KIND.withdrawal,
         )
         transactions = Transaction.objects.filter(sep6_24_qparams | sep31_qparams)
         num_completed = 0
@@ -62,6 +64,7 @@ class Command(BaseCommand):
                 )
                 continue
 
+            transaction.refresh_from_db()
             if transaction.status == Transaction.STATUS.pending_receiver:
                 logger.error(
                     f"Transaction {transaction.id} status must be "
@@ -74,10 +77,14 @@ class Command(BaseCommand):
             ]:
                 if transaction.amount_fee is None:
                     if registered_fee_func == calculate_fee:
+                        op = {
+                            Transaction.KIND.withdrawal: settings.OPERATION_WITHDRAWAL,
+                            Transaction.KIND.send: Transaction.KIND.send,
+                        }[transaction.kind]
                         transaction.amount_fee = calculate_fee(
                             {
                                 "amount": transaction.amount_in,
-                                "operation": Transaction.KIND.send,
+                                "operation": op,
                                 "asset_code": transaction.asset.code,
                             }
                         )
@@ -93,7 +100,8 @@ class Command(BaseCommand):
                     transaction.completed_at = datetime.now(timezone.utc)
             elif transaction.status not in [
                 Transaction.STATUS.error,
-                Transaction.STATUS.pending_info_update,
+                Transaction.STATUS.pending_transaction_info_update,
+                Transaction.STATUS.pending_customer_info_update,
             ]:
                 logger.error(
                     f"Transaction {transaction.id} was moved to invalid status"
