@@ -1,12 +1,20 @@
-import logging
 import time
+from decimal import Decimal
+
 from django.core.management import BaseCommand, CommandError
-from polaris.deposit.utils import create_stellar_deposit
-from polaris.integrations import registered_deposit_integration as rdi
+
+from polaris import settings
+from polaris.utils import create_stellar_deposit
+from polaris.integrations import (
+    registered_deposit_integration as rdi,
+    registered_rails_integration as rri,
+    registered_fee_func,
+    calculate_fee,
+)
 from polaris.models import Transaction
+from polaris.utils import Logger
 
-
-logger = logging.getLogger(__name__)
+logger = Logger(__name__)
 
 
 def execute_deposit(transaction: Transaction) -> bool:
@@ -26,9 +34,21 @@ def execute_deposit(transaction: Transaction) -> bool:
             f"Unexpected transaction status: {transaction.status}, expecting "
             f"{transaction.STATUS.pending_user_transfer_start}"
         )
+    elif transaction.amount_fee is None:
+        if registered_fee_func == calculate_fee:
+            transaction.amount_fee = calculate_fee(
+                {
+                    "amount": transaction.amount_in,
+                    "operation": settings.OPERATION_DEPOSIT,
+                    "asset_code": transaction.asset.code,
+                }
+            )
+        else:
+            transaction.amount_fee = Decimal(0)
     transaction.status = Transaction.STATUS.pending_anchor
     transaction.status_eta = 5  # Ledger close time.
     transaction.save()
+    logger.info(f"Transaction {transaction.id} now pending_anchor, initiating deposit")
     # launch the deposit Stellar transaction.
     return create_stellar_deposit(transaction.id)
 
@@ -40,7 +60,7 @@ class Command(BaseCommand):
     restarting every 10 seconds (or a user-defined time period)
     """
 
-    def add_arguments(self, parser):
+    def add_arguments(self, parser):  # pragma: no cover
         parser.add_argument(
             "--loop",
             action="store_true",
@@ -51,12 +71,11 @@ class Command(BaseCommand):
             "--interval",
             "-i",
             type=int,
-            nargs=1,
             help="The number of seconds to wait before "
             "restarting command. Defaults to 10.",
         )
 
-    def handle(self, *args, **options):
+    def handle(self, *args, **options):  # pragma: no cover
         if options.get("loop"):
             while True:
                 self.execute_deposits()
@@ -66,19 +85,42 @@ class Command(BaseCommand):
 
     @classmethod
     def execute_deposits(cls):
+        """
+        Right now, execute_deposits assumes all pending deposits are SEP-6 or 24
+        transactions. This may change in the future if Polaris adds support for
+        another SEP that checks for incoming deposits.
+        """
         pending_deposits = Transaction.objects.filter(
             kind=Transaction.KIND.deposit,
             status=Transaction.STATUS.pending_user_transfer_start,
         )
         try:
-            ready_transactions = rdi.poll_pending_deposits(pending_deposits)
-        except NotImplementedError as e:
-            raise CommandError(e)
+            ready_transactions = rri.poll_pending_deposits(pending_deposits)
+        except Exception:  # pragma: no cover
+            # We don't know if poll_pending_deposits() will raise an exception
+            # every time its called, but we're going to assume it was a special
+            # case and allow the process to continue running by returning instead
+            # of re-raising the error. The anchor should see the log messages and
+            # fix the issue if it is reoccurring.
+            logger.exception("poll_pending_deposits() threw an unexpected exception")
+            return
+        if ready_transactions is None:
+            raise CommandError(
+                "poll_pending_deposits() returned None. "
+                "Ensure is returns a list of transaction objects."
+            )
         for transaction in ready_transactions:
             try:
                 success = execute_deposit(transaction)
             except ValueError as e:
-                logger.error(f"poll_pending_transactions: {str(e)}")
+                logger.error(str(e))
                 continue
             if success:
-                rdi.after_deposit(transaction)
+                # Get updated status
+                transaction.refresh_from_db()
+                try:
+                    rdi.after_deposit(transaction)
+                except Exception:  # pragma: no cover
+                    # Same situation as poll_pending_deposits(), we should assume
+                    # this won't happen every time, so we don't stop the loop.
+                    logger.exception("after_deposit() threw an unexpected exception")
