@@ -174,7 +174,7 @@ class Asset(TimeStampedModel):
     """Optional maximum amount. No limit if not specified."""
 
     send_fee_fixed = models.DecimalField(
-        null=True, blank=True, max_digits=30, decimal_places=7
+        default=0, blank=True, max_digits=30, decimal_places=7
     )
     """
     Optional fixed (base) fee for sending this asset in units of this asset. 
@@ -183,7 +183,7 @@ class Asset(TimeStampedModel):
     """
 
     send_fee_percent = models.DecimalField(
-        null=True,
+        default=0,
         blank=True,
         max_digits=30,
         decimal_places=7,
@@ -263,7 +263,8 @@ class Transaction(models.Model):
         # messages are None because they are never displayed to user
         "pending_sender": None,
         "pending_receiver": None,
-        "pending_info_update": None,
+        "pending_transaction_info_update": None,
+        "pending_customer_info_update": None,
         # Shared
         "completed": _("complete"),
         "error": _("error"),
@@ -274,7 +275,7 @@ class Transaction(models.Model):
     STATUS = PolarisChoices(*list(status_to_message.keys()))
 
     MEMO_TYPES = PolarisChoices("text", "id", "hash")
-    """Type for the ``deposit_memo``. Can be either `hash`, `id`, or `text`"""
+    """Type for the ``memo``. Can be either `hash`, `id`, or `text`"""
 
     PROTOCOL = PolarisChoices("sep6", "sep24", "sep31")
     """Values for `protocol` column"""
@@ -358,9 +359,12 @@ class Transaction(models.Model):
     * **pending_stellar**
     
         transaction has been submitted to Stellar network, but is not yet confirmed.
-    * **pending_info_update**
+    * **pending_transaction_info_update**
     
-        certain pieces of information need to be updated by the sending anchor.
+        transaction details must be updated to successfully execute transaction off-chain
+    * **pending_customer_info_update**
+    
+        customer (SEP-12) information must be updated to facilitate transactions
     * **pending_receiver**
     
         payment is being processed by the receiving anchor.
@@ -438,11 +442,10 @@ class Transaction(models.Model):
     withdrawal or send, Stellar address in the case of a deposit).
     """
 
-    required_info_update = models.TextField(null=True, blank=True)
+    required_info_updates = models.TextField(null=True, blank=True)
     """
     (SEP31) (optional) A set of fields that require an update from the sender, 
-    in the same format as described in /info. Fields should be broken out by 
-    sender, receiver, and transaction as specified in /info.
+    in the same format as described in /info.
     """
 
     required_info_message = models.TextField(null=True, blank=True)
@@ -451,13 +454,13 @@ class Transaction(models.Model):
     require updated information from the sender
     """
 
-    deposit_memo = models.TextField(null=True, blank=True)
+    memo = models.TextField(null=True, blank=True)
     """
     (optional) Value of memo to attach to transaction, for hash this should
     be base64-encoded.
     """
 
-    deposit_memo_type = models.CharField(
+    memo_type = models.CharField(
         choices=MEMO_TYPES, default=MEMO_TYPES.text, max_length=10
     )
     """
@@ -465,33 +468,9 @@ class Transaction(models.Model):
     transaction, one of text, id or hash.
     """
 
-    withdraw_anchor_account = models.TextField(null=True, blank=True)
+    receiving_anchor_account = models.TextField(null=True, blank=True)
     """
-    (optional) The stellar account ID of the user that wants to do the 
-    withdrawal. This is only needed if the anchor requires KYC information for
-    withdrawal. The anchor can use account to look up the user's KYC 
-    information.
-    """
-
-    withdraw_memo = models.TextField(null=True, blank=True)
-    """(if specified) use this memo in the payment transaction to the anchor."""
-
-    withdraw_memo_type = models.CharField(
-        choices=MEMO_TYPES, default=MEMO_TYPES.text, max_length=10
-    )
-    """Field for the ``MEMO_TYPES`` Choices"""
-
-    send_memo = models.TextField(null=True, blank=True)
-    """The memo to attach to the stellar payment"""
-
-    send_memo_type = models.CharField(
-        choices=MEMO_TYPES, default=MEMO_TYPES.text, max_length=10
-    )
-    """Field for the ``MEMO_TYPES`` Choices"""
-
-    send_anchor_account = models.TextField(null=True, blank=True)
-    """
-    Stellar account to send payment to
+    Stellar account to send payment or withdrawal funds to
     """
 
     refunded = models.BooleanField(default=False)
