@@ -18,6 +18,7 @@ from stellar_sdk.keypair import Keypair
 from stellar_sdk.exceptions import Ed25519PublicKeyInvalidError
 
 from polaris import settings
+from polaris.templates import Template
 from polaris.utils import (
     render_error_response,
     Logger,
@@ -40,6 +41,7 @@ from polaris.integrations import (
     registered_deposit_integration as rdi,
     registered_scripts_func,
     registered_fee_func,
+    registered_toml_func,
     calculate_fee,
 )
 
@@ -58,15 +60,15 @@ def post_interactive_deposit(request: Request) -> Response:
     flow. The following steps are taken during this process:
 
         1. URL arguments are parsed and validated.
-        2. content_for_transaction() is called to retrieve the form used to
+        2. form_for_transaction() is called to retrieve the form used to
            submit this request. This function is implemented by the anchor.
         3. The form is used to validate the data submitted, and if the form
            is a TransactionForm, the fee for the transaction is calculated.
         4. after_form_validation() is called to allow the anchor to process
            the data submitted. This function should change the application
-           state such that the next call to content_for_transaction() returns
+           state such that the next call to form_for_transaction() returns
            the next form in the flow.
-        5. content_for_transaction() is called again to retrieve the next
+        5. form_for_transaction() is called again to retrieve the next
            form to be served to the user. If a form is returned, the
            function redirects to GET /transaction/deposit/webapp. Otherwise,
            The user's session is invalidated, the transaction status is
@@ -81,10 +83,13 @@ def post_interactive_deposit(request: Request) -> Response:
     callback = args_or_error["callback"]
     amount = args_or_error["amount"]
 
-    content = rdi.content_for_transaction(transaction, post_data=request.POST)
-    if not (content and content.get("form")):
+    form = rdi.form_for_transaction(transaction, post_data=request.POST)
+    content = rdi.content_for_template(
+        Template.DEPOSIT, form=form, transaction=transaction
+    )
+    if not form:
         logger.error(
-            "Initial content_for_transaction() call returned None in "
+            "Initial form_for_transaction() call returned None in "
             f"POST request for transaction: {transaction.id}"
         )
         if transaction.status != transaction.STATUS.incomplete:
@@ -101,9 +106,9 @@ def post_interactive_deposit(request: Request) -> Response:
             content_type="text/html",
         )
 
-    form = content.get("form")
     if not form.is_bound:
         # The anchor must initialize the form with the request.POST data
+        logger.error("form returned was not initialized with POST data, returning 500")
         return render_error_response(
             _("Unable to validate form submission."),
             status_code=500,
@@ -116,7 +121,10 @@ def post_interactive_deposit(request: Request) -> Response:
             transaction.save()
 
         rdi.after_form_validation(form, transaction)
-        if rdi.content_for_transaction(transaction):
+        next_form = rdi.form_for_transaction(transaction)
+        if next_form or rdi.content_for_template(
+            Template.DEPOSIT, form=next_form, transaction=transaction
+        ):
             args = {"transaction_id": transaction.id, "asset_code": asset.code}
             if amount:
                 args["amount"] = amount
@@ -137,7 +145,7 @@ def post_interactive_deposit(request: Request) -> Response:
             return redirect(f"{url}?{args}")
 
     else:
-        scripts = registered_scripts_func(content)
+        scripts = registered_scripts_func({"form": form, **content})
 
         url_args = {"transaction_id": transaction.id, "asset_code": asset.code}
         if callback:
@@ -159,7 +167,7 @@ def post_interactive_deposit(request: Request) -> Response:
 
 
 @api_view(["GET"])
-@renderer_classes([TemplateHTMLRenderer])
+@renderer_classes([])
 @check_authentication()
 def complete_interactive_deposit(request: Request) -> Response:
     """
@@ -203,7 +211,7 @@ def get_interactive_deposit(request: Request) -> Response:
            returned, this function redirects to the URL. However, the session
            cookie should still be included in the response so future calls to
            GET /transactions/deposit/interactive/complete are authenticated.
-        3. content_for_transaction() is called to retrieve the next form to
+        3. form_for_transaction() is called to retrieve the next form to
            render to the user.
         4. get and post URLs are constructed with the appropriate arguments
            and passed to the response to be rendered to the user.
@@ -221,8 +229,11 @@ def get_interactive_deposit(request: Request) -> Response:
     if url:  # The anchor uses a standalone interactive flow
         return redirect(url)
 
-    content = rdi.content_for_transaction(transaction, amount=amount)
-    if not content:
+    form = rdi.form_for_transaction(transaction, amount=amount)
+    content = rdi.content_for_template(
+        Template.DEPOSIT, form=form, transaction=transaction
+    )
+    if not (form or content):
         logger.error("The anchor did not provide content, unable to serve page.")
         if transaction.status != transaction.STATUS.incomplete:
             return render_error_response(
@@ -237,8 +248,13 @@ def get_interactive_deposit(request: Request) -> Response:
             status_code=500,
             content_type="text/html",
         )
+    elif content is None:
+        content = {}
 
-    scripts = registered_scripts_func(content)
+    if form:
+        scripts = registered_scripts_func({"form": form, **content})
+    else:
+        scripts = registered_scripts_func(content)
 
     url_args = {"transaction_id": transaction.id, "asset_code": asset.code}
     if callback:
@@ -246,15 +262,18 @@ def get_interactive_deposit(request: Request) -> Response:
     if amount:
         url_args["amount"] = amount
 
+    toml_data = registered_toml_func()
     post_url = f"{reverse('post_interactive_deposit')}?{urlencode(url_args)}"
     get_url = f"{reverse('get_interactive_deposit')}?{urlencode(url_args)}"
     content.update(
+        form=form,
         post_url=post_url,
         get_url=get_url,
         scripts=scripts,
         operation=settings.OPERATION_DEPOSIT,
         asset=asset,
         use_fee_endpoint=registered_fee_func != calculate_fee,
+        org_logo_url=toml_data.get("DOCUMENTATION", {}).get("ORG_LOGO"),
     )
 
     return Response(content, template_name="deposit/form.html")
@@ -322,8 +341,8 @@ def deposit(account: str, request: Request) -> Response:
         status=Transaction.STATUS.incomplete,
         to_address=account,
         protocol=Transaction.PROTOCOL.sep24,
-        deposit_memo=memo,
-        deposit_memo_type=request.POST.get("memo_type") or Transaction.MEMO_TYPES.hash,
+        memo=memo,
+        memo_type=request.POST.get("memo_type") or Transaction.MEMO_TYPES.hash,
     )
     logger.info(f"Created deposit transaction {transaction_id}")
 
