@@ -15,6 +15,7 @@ from rest_framework.request import Request
 from rest_framework.renderers import TemplateHTMLRenderer, JSONRenderer
 
 from polaris import settings
+from polaris.templates import Template
 from polaris.utils import (
     render_error_response,
     Logger,
@@ -37,6 +38,7 @@ from polaris.integrations import (
     registered_withdrawal_integration as rwi,
     registered_scripts_func,
     registered_fee_func,
+    registered_toml_func,
     calculate_fee,
 )
 
@@ -55,15 +57,15 @@ def post_interactive_withdraw(request: Request) -> Response:
     flow. The following steps are taken during this process:
 
         1. URL arguments are parsed and validated.
-        2. content_for_transaction() is called to retrieve the form used to
+        2. form_for_transaction() is called to retrieve the form used to
            submit this request. This function is implemented by the anchor.
         3. The form is used to validate the data submitted, and if the form
            is a TransactionForm, the fee for the transaction is calculated.
         4. after_form_validation() is called to allow the anchor to process
            the data submitted. This function should change the application
-           state such that the next call to content_for_transaction() returns
+           state such that the next call to form_for_transaction() returns
            the next form in the flow.
-        5. content_for_transaction() is called again to retrieve the next
+        5. form_for_transaction() is called again to retrieve the next
            form to be served to the user. If a form is returned, the
            function redirects to GET /transaction/deposit/webapp. Otherwise,
            The user's session is invalidated, the transaction status is
@@ -78,11 +80,13 @@ def post_interactive_withdraw(request: Request) -> Response:
     callback = args_or_error["callback"]
     amount = args_or_error["amount"]
 
-    content = rwi.content_for_transaction(transaction, post_data=request.POST)
-    if not (content and content.get("form")):
+    form = rwi.form_for_transaction(transaction, post_data=request.POST)
+    content = rwi.content_for_template(
+        Template.WITHDRAW, form=form, transaction=transaction
+    )
+    if not form:
         logger.error(
-            "Initial content_for_transaction() call returned None "
-            f"for {transaction.id}"
+            "Initial form_for_transaction() call returned None " f"for {transaction.id}"
         )
         if transaction.status != transaction.STATUS.incomplete:
             return render_error_response(
@@ -98,9 +102,9 @@ def post_interactive_withdraw(request: Request) -> Response:
             content_type="text/html",
         )
 
-    form = content.get("form")
     if not form.is_bound:
         # The anchor must initialize the form with the request.POST data
+        logger.error("form returned was not initialized with POST data, returning 500")
         return render_error_response(
             _("Unable to validate form submission."),
             status_code=500,
@@ -113,8 +117,10 @@ def post_interactive_withdraw(request: Request) -> Response:
             transaction.save()
 
         rwi.after_form_validation(form, transaction)
-
-        if rwi.content_for_transaction(transaction):
+        next_form = rwi.form_for_transaction(transaction)
+        if next_form or rwi.content_for_template(
+            Template.WITHDRAW, form=next_form, transaction=transaction
+        ):
             args = {"transaction_id": transaction.id, "asset_code": asset.code}
             if amount:
                 args["amount"] = amount
@@ -138,7 +144,7 @@ def post_interactive_withdraw(request: Request) -> Response:
             # appropriately sized string for the `HashMemo`.
             transaction_id_hex = transaction.id.hex
             padded_hex_memo = "0" * (64 - len(transaction_id_hex)) + transaction_id_hex
-            transaction.withdraw_memo = memo_hex_to_base64(padded_hex_memo)
+            transaction.memo = memo_hex_to_base64(padded_hex_memo)
             # Update status
             # This signals to the wallet that the transaction can be submitted
             transaction.status = Transaction.STATUS.pending_user_transfer_start
@@ -148,7 +154,7 @@ def post_interactive_withdraw(request: Request) -> Response:
             return redirect(f"{url}?{args}")
 
     else:
-        scripts = registered_scripts_func(content)
+        scripts = registered_scripts_func({"form": form, **content})
 
         url_args = {"transaction_id": transaction.id, "asset_code": asset.code}
         if callback:
@@ -156,6 +162,7 @@ def post_interactive_withdraw(request: Request) -> Response:
         if amount:
             url_args["amount"] = amount
 
+        toml_data = registered_toml_func()
         post_url = f"{reverse('post_interactive_deposit')}?{urlencode(url_args)}"
         get_url = f"{reverse('get_interactive_deposit')}?{urlencode(url_args)}"
         content.update(
@@ -165,6 +172,7 @@ def post_interactive_withdraw(request: Request) -> Response:
             operation=settings.OPERATION_WITHDRAWAL,
             asset=asset,
             use_fee_endpoint=registered_fee_func != calculate_fee,
+            org_logo_url=toml_data.get("DOCUMENTATION", {}).get("ORG_LOGO"),
         )
         return Response(content, template_name="withdraw/form.html", status=422)
 
@@ -214,7 +222,7 @@ def get_interactive_withdraw(request: Request) -> Response:
            returned, this function redirects to the URL. However, the session
            cookie should still be included in the response so future calls to
            GET /transactions/withdraw/interactive/complete are authenticated.
-        3. content_for_transaction() is called to retrieve the next form to
+        3. form_for_transaction() is called to retrieve the next form to
            render to the user.
         4. get and post URLs are constructed with the appropriate arguments
            and passed to the response to be rendered to the user.
@@ -232,8 +240,11 @@ def get_interactive_withdraw(request: Request) -> Response:
     if url:  # The anchor uses a standalone interactive flow
         return redirect(url)
 
-    content = rwi.content_for_transaction(transaction, amount=amount)
-    if not content:
+    form = rwi.form_for_transaction(transaction, amount=amount)
+    content = rwi.content_for_template(
+        Template.WITHDRAW, form=form, transaction=transaction
+    )
+    if not (form or content):
         logger.error("The anchor did not provide content, unable to serve page.")
         if transaction.status != transaction.STATUS.incomplete:
             return render_error_response(
@@ -248,8 +259,13 @@ def get_interactive_withdraw(request: Request) -> Response:
             status_code=500,
             content_type="text/html",
         )
+    elif content is None:
+        content = {}
 
-    scripts = registered_scripts_func(content)
+    if form:
+        scripts = registered_scripts_func({"form": form, **content})
+    else:
+        scripts = registered_scripts_func(content)
 
     url_args = {"transaction_id": transaction.id, "asset_code": asset.code}
     if callback:
@@ -260,6 +276,7 @@ def get_interactive_withdraw(request: Request) -> Response:
     post_url = f"{reverse('post_interactive_withdraw')}?{urlencode(url_args)}"
     get_url = f"{reverse('get_interactive_withdraw')}?{urlencode(url_args)}"
     content.update(
+        form=form,
         post_url=post_url,
         get_url=get_url,
         scripts=scripts,
@@ -319,8 +336,8 @@ def withdraw(account: str, request: Request) -> Response:
         asset=asset,
         kind=Transaction.KIND.withdrawal,
         status=Transaction.STATUS.incomplete,
-        withdraw_anchor_account=asset.distribution_account,
-        withdraw_memo_type=Transaction.MEMO_TYPES.hash,
+        receiving_anchor_account=asset.distribution_account,
+        memo_type=Transaction.MEMO_TYPES.hash,
         protocol=Transaction.PROTOCOL.sep24,
     )
     logger.info(f"Created withdrawal transaction {transaction_id}")
