@@ -11,7 +11,6 @@ import pytest
 from stellar_sdk import Keypair, TransactionEnvelope
 
 from polaris import settings
-from polaris.utils import SUCCESS_XDR
 from polaris.tests.helpers import (
     mock_check_auth_success,
     interactive_jwt_payload,
@@ -21,7 +20,7 @@ from polaris.tests.helpers import (
 WEBAPP_PATH = "/sep24/transactions/deposit/webapp"
 DEPOSIT_PATH = "/sep24/transactions/deposit/interactive"
 HORIZON_SUCCESS_RESPONSE = {
-    "result_xdr": SUCCESS_XDR,
+    "successful": True,
     "id": "test_stellar_id",
     "paging_token": "123456789",
 }
@@ -271,7 +270,7 @@ def test_interactive_auth_new_transaction(client, acc1_usd_deposit_transaction_f
     were not authenticated for the specified transaction.
     """
     deposit = acc1_usd_deposit_transaction_factory()
-    # So that content_for_transaction() returns TransactionForm
+    # So that form_for_transaction() returns TransactionForm
     deposit.amount_in = None
     deposit.save()
 
